[![PyPI Downloads](https://static.pepy.tech/badge/janssen)](https://pepy.tech/projects/janssen)
[![License](https://img.shields.io/pypi/l/janssen.svg)](https://github.com/debangshu-mukherjee/janssen/blob/main/LICENSE.md)
[![PyPI version](https://img.shields.io/pypi/v/janssen.svg)](https://pypi.python.org/pypi/janssen)
[![Python Versions](https://img.shields.io/pypi/pyversions/janssen.svg)](https://pypi.python.org/pypi/janssen)
[![Documentation Status](https://readthedocs.org/projects/janssen/badge/?version=latest)](https://janssen.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17041632.svg)](https://doi.org/10.5281/zenodo.17041632)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![codecov](https://codecov.io/gh/debangshu-mukherjee/janssen/branch/main/graph/badge.svg)](https://codecov.io/gh/debangshu-mukherjee/janssen)
[![jax_badge](https://tinyurl.com/mucknrvu)](https://docs.jax.dev/)

# Janssen: Optical Microscopy with JAX

Janssen is a JAX-based library for optical microscopy simulations and ptychographic reconstructions. It provides differentiable implementations of optical propagation, lens simulations, and phase retrieval algorithms, all optimized for GPU acceleration through JAX.
